// ************************************************************************
// BRENDAN.INClude file                           Ver 1.0 Fall 97-Winter 98
// Definitions of assorted basic objects and effects                  *****
// ************************************************************************

#include "colors.inc"
#include "tex_b.inc"                   //edited from textures.v2
#include "shapes.inc"
#include "woods_b.inc"                 //edited from woods.inc

// ************************************************************************
// CONSTANTS

#declare None = 0
#declare LittleSpan = 5
#declare SmallSpan = 10
#declare LargeSpan = 20
#declare ThirdSpan = 30
#declare DoubleSpan = 40

// ************************************************************************
//  Define Lights
// ************************************************************************

#declare SE_Spot_1 =
light_source {
   < 50, 50, -50 >
   color White
   spotlight
   radius 10
   falloff 15
   tightness 5
   point_at < 0, 0, 0 >
//   atmospheric_attenuation on
             } // end light SE Spot 1

#declare SE_Spot_2 =
light_source {
   < 100, 75, -100 >
   color White
   spotlight
   radius 15
   falloff 20
   tightness 10
   point_at < 0, 0, 0 >
             } // end light SE Spot 2

#declare SW_Spot_1 =
light_source {
   < -50, 50, -50 >
   color White
   spotlight
   radius 15
   falloff 20
   tightness 10
   point_at < 0, 0, 0 >
             } // end light SW Spot 1

#declare SW_Spot_2 =
light_source {
   < -100, 50, -100 >
   color White
   spotlight
   radius 15
   falloff 20
   tightness 10
   point_at < 0, 0, 0 >
             } // end light SW Spot 2

#declare SW_Spot_2S =                  //with umbra
light_source {
   < -100, 50, -100 >
   color White
   spotlight
   radius 15
   falloff 20
   tightness 10
   area_light < 2, 0, 0 >, < 0, 0, 2 >, 2, 2
   adaptive 1
   jitter
   point_at < 0, 0, 0 >
             } // end light SW Spot 2S

// ************************************************************************
//  Define Cameras                                                   
// ************************************************************************

#declare Camera_1 =
camera {
   location  < -25,  25, -25 >         //SW of 0 0 0
   direction <   0,   0,   1 >
   look_at   <   0,   5,   0 >         //scene center
} // end Camera 1

#declare Camera_2 =
camera {
   location  <  25,  25, -25 >         //SE of 0 0 0
   direction <   0,   0,   1 >
   look_at   <   0,   5,   0 >         //scene center
} // end Camera 2

#declare Camera_3 =
camera {
   location  < -50,  50, -50 >         //farther SW of 0 0 0
   direction <   0,   0,   1 >
   look_at   <   0,   5,   0 >         //scene center
} // end Camera 3

#declare Camera_4 =
camera {
   location  <  50,  50, -50 >         //farther SE of 0 0 0
   direction <   0,   0,   1 >
   look_at   <   0,   5,   0 >         //scene center
} // end Camera 2

#declare Camera_S =
camera {
   location  <   0,  25, -25 >         //S of 0 0 0
   direction <   0,   0,   1 >
   look_at   <   0,   5,   0 >         //scene center
} // end Camera South

#declare Camera_N =
camera {
   location  <   0,  25,  25 >         //N of 0 0 0
   direction <   0,   0,   1 >
   look_at   <   0,   5,   0 >         //scene center
} // end Camera North

#declare Camera_E =
camera {
   location  <  25,  25,   0 >         //E of 0 0 0
   direction <   0,   0,   1 >
   look_at   <   0,   5,   0 >         //scene center
} // end Camera E

#declare Camera_W =
camera {
   location  < -25,  25,   0 >         //W of 0 0 0
   direction <   0,   0,   1 >
   look_at   <   0,   5,   0 >         //scene center
} // end Camera 1

// ************************************************************************
//  Define Floors                                                     *****
// ************************************************************************

#declare Check_Floor =
plane { y, 0
   pigment {
      checker color White color Black
      scale 10
           } //end pigment
   finish {
      ambient 0.2
      diffuse 0.8
          } //end finish
   hollow
      } // end Plane Check Floor

#declare Gray50_Floor =
plane { y, 0
   pigment {
      colour Gray50
           } //end pigment
   finish {
      ambient 0.2
      diffuse 0.8
          } //end finish
   hollow
      } // end Gray 50 Floor

#declare Grass_Floor =
plane { y, 0
   texture { Grass
             scale 4
           } //end texture
   finish {
      ambient 0.2
      diffuse 0.9
          } //end finish
   hollow
      } // end Grass Floor

#declare Test_Floor =
plane { y, 0
   texture { GreenYellow_Tex
             scale 4
           } //end texture
   finish {
      ambient 0.2
      diffuse 0.9
          } //end finish
   hollow
      } // end Test Floor

#declare Clip_Floor =
plane { y, 0
   texture { GreenYellow_Tex
             scale 4
           } //end texture
   finish {
      ambient 0.2
      diffuse 0.8
          } //end finish
   hollow
   clipped_by { UnitBox scale < 1000, 1, 1000 > }
      } // end Clipped Floor

// ************************************************************************
//  Define Basic Objects                                              
// ************************************************************************

//  Define a Test Box

#declare TestBox =
object { UnitBox
         scale 2.5 }

// ************************************************************************

//  Define a basic cylinder

#declare Post01 =
object { Disk_Y
         scale 2.5
       } // end Post 01

#declare Post02 =
object { Disk_Y
         scale 1
       } // end Post 02

#declare Post03 =
object { Disk_X
         scale 1
       } // end Post 03

// ************************************************************************

//  Define three square axis posts

#declare Post_X =
object { UnitBox
         scale < 2, 0.5, 0.5 >
       } // end Post X axis

#declare Post_Y =
object { UnitBox
         scale < 0.5, 2, 0.5 >
       } // end Post Y axis

#declare Post_Z =
object { UnitBox
         scale < 0.5, 0.5, 2 >
       } // end Post Z axis

// ************************************************************************

#declare Piriform =                    // from SHAPESQ.INC
 quartic 
  {< 4,   0,   0,   -4,  0,   0,   0,   0,   0,  0,
     0,   0,   0,    0,  0,   0,   0,   0,   0,  0,
     0,   0,   0,    0,  0,   1,   0,   0,   0,  0,
     0,   0,   1,    0,  0>
  }

// ************************************************************************

#declare Semi_Circle =
object {
   Disk_Z  scale 1
           clipped_by { plane { -y, 0 } }
       }  // end Semi Circle

// ************************************************************************

#declare GrayRod =
object {
   Cylinder_X
   clipped_by {
      plane {  x, 1 }
      plane { -x, 1 }
              }//end clip
   texture { Gray75_Tex }
   scale < 1.0, 0.2, 0.2 > }

// ************************************************************************

#declare XCyl_1 =
object { Disk_X  scale < 1.0 1.0 1.0 > }  // end X Cylinder 1

#declare YCyl_1 =
object { Disk_Y  scale < 1.0 1.0 1.0 > }  // end Y Cylinder 1

#declare ZCyl_1 =
object { Disk_Z  scale < 1.0 1.0 1.0 > }  // end Z Cylinder 1


#declare YCyl_2 =
object { Disk_Y  scale < 0.8 1.1 0.8 > }  // end Y Cylinder 2

#declare ZCyl_2 =
object { Disk_Z  scale < 0.7 0.7 1.1 > }  // end Z Cylinder 2

#declare ZCyl_3 =
object { Disk_Z  scale < 0.95 0.95 1.1 > }  // end Z Cylinder 3

// ************************************************************************

#declare Arch_Z =
difference {
   object { ZCyl_1 }
   object { ZCyl_2 }
   clipped_by { plane { -y, 0 } }
           } // end diference Arch_Z

// ************************************************************************

#declare Arch_Z2 =
difference {
   object { ZCyl_1 }
   object { ZCyl_3 }
   clipped_by { plane { -y, 0 } }
           } // end diference Arch_Z

// ***********************************************************************

/*
//   DEFINE  Crossed arches        from MIST.POV

#declare Span = difference {
    object { UnitBox }
    object { Disk_Z scale <0.85, 0.75, 1.5> } // cross-arches
    object { Disk_X scale <1.15, 0.7, 0.7> }  // lengthwise arches
    clipped_by { plane { -y,0 } }
    texture { T_Wood2 }
}
*/

// ************************************************************************

//   DEFINE   Round wall section: scale, texture to suit

#declare Cylinder_Wall =
difference {
   object { YCyl_1 }
   object { YCyl_2 }
           } //end difference Cylndr wall

// ************************************************************************
//                               GRID MARKERS                         *****
// ************************************************************************

// X-AXIS  Red spheres spaced 50 units apart centered on < 0 0 0 >

#declare X_Axis =
union {
sphere { <0, 0, 0>, 2                  //Center of scene <0 0 0>
   pigment { Red
           } //end pigment
   finish  { ambient 0.15
             diffuse 0.7
           } //end finish
       } // end Sphere
sphere { <0, 0, 0>, 1
   pigment { Red
           } //end pigment
   finish  { ambient 0.15
             diffuse 0.7
           } //end finish
   translate < 50, 0, 0 >
       } // end Sphere
sphere { <0, 0, 0>, 1
   pigment { Red
           } //end pigment
   finish  { ambient 0.15
             diffuse 0.7
           } //end finish
   translate < 100, 0, 0 >
       } // end Sphere
sphere { <0, 0, 0>, 1
   pigment { Red
           } //end pigment
   finish  { ambient 0.15
             diffuse 0.7
           } //end finish
   translate < -50, 0, 0 >
       } // end Sphere
sphere { <0, 0, 0>, 1
   pigment { Red
           } //end pigment
   finish  { ambient 0.15
             diffuse 0.7
           } //end finish
   translate < -100, 0, 0 >
       } // end Sphere
} // end Union X_Axis

// ************************************************************************

// Z-AXIS  Green spheres spaced 50 units apart centered on < 0 0 0 >

#declare Z_Axis =
union {
sphere { <0, 0, 0>, 1
   pigment { Green
           } //end pigment
   finish  { ambient 0.15
             diffuse 0.7
           } //end finish
   translate < 0, 0, 50 > } // end Sphere
sphere { <0, 0, 0>, 1
   pigment { Green
           } //end pigment
   finish  { ambient 0.15
             diffuse 0.7
           } //end finish
   translate < 0, 0, 100 > } // end Sphere
sphere { <0, 0, 0>, 1
   pigment { Green
           } //end pigment
   finish  { ambient 0.15
             diffuse 0.7
           } //end finish
   translate < 0, 0, -50 > } // end Sphere
sphere { <0, 0, 0>, 1
   pigment { Green
           } //end pigment
   finish  { ambient 0.15
             diffuse 0.7
           } //end finish
   translate < 0, 0, -100 > } // end Sphere
} // end union Z Axis

// ************************************************************************

// Define a x-axis rod                 

#declare XRod =
object {
   Cylinder_X
   clipped_by {
      plane {  x, 5 }
      plane { -x, 5 }
              }
   texture { Red_Tex }
   scale < 1.0, 0.25, 0.25 > }

// Define a z-axis rod

#declare ZRod =
object {
   Cylinder_Z
   clipped_by {
      plane {  z, 5 }
      plane { -z, 5 }
              }
   texture { Yellow_Tex }
   scale < 0.25, 0.25, 1.0 > }

// Define a y-axis rod

#declare YRod =
object {
   Cylinder_Y
   clipped_by {
      plane {  y, 5 }
      plane { -y, 5 }
              }
   texture { Green_Tex }
   scale < 0.25, 1.0, 0.25 > }

// ************************************************************************

//   DEFINE  a 3-axis grid marker

#declare Mark01 =
union {
   object { XRod }
   object { YRod }
   object { ZRod }
      } // end Marker 1

// ************************************************************************

/*

// Define a grid of rods

#declare X_Grid =
union {
   object { XRod }
   object { XRod translate < 0, 0,   10 > }
   object { XRod translate < 0, 0,   20 > }
   object { XRod translate < 0, 0,   30 > }
   object { XRod translate < 0, 0,   40 > }
   object { XRod translate < 0, 0,   50 > }
   object { XRod translate < 0, 0,  100 > }
   object { XRod translate < 0, 0,  -10 > }
   object { XRod translate < 0, 0,  -20 > }
   object { XRod translate < 0, 0,  -30 > }
   object { XRod translate < 0, 0,  -40 > }
   object { XRod translate < 0, 0,  -50 > }
   object { XRod translate < 0, 0, -100 > }
      } // end union X Grid

#declare Z_Grid =
union {
   object { ZRod }
   object { ZRod translate <   10, 0, 0 > }
   object { ZRod translate <   20, 0, 0 > }
   object { ZRod translate <   30, 0, 0 > }
   object { ZRod translate <   40, 0, 0 > }
   object { ZRod translate <   50, 0, 0 > }
   object { ZRod translate <  100, 0, 0 > }
   object { ZRod translate <  -10, 0, 0 > }
   object { ZRod translate <  -20, 0, 0 > }
   object { ZRod translate <  -30, 0, 0 > }
   object { ZRod translate <  -40, 0, 0 > }
   object { ZRod translate <  -50, 0, 0 > }
   object { ZRod translate < -100, 0, 0 > }
      } // end union Z Grid

*/

// ************************************************************************
//          End file  BRENDAN.INC  Michael Brendan Hurley Fall 1997
// ************************************************************************
