// DO_Chair.inc:  chairs, stools

//    DO_Chair1 - wooden chair with green cushion, .5 wide, .5 deep
//    DO_Chair2 - wooden chair with green cushion and arm rests
//    DO_FootStool1 - a small wooden footstool with green cushion
//    DO_Stool1 - wooden stool with four legs
//    DO_Chair3 - windsor style wooden chair, .5 wide, .45 deep, .9 tall

// The chairs are oriented so that someone seated in the chair would face
// in the -z direction.
// The bottom center of the chairs at <0,0,0>: units = meters

#ifndef (DO_CHAIR_INC)
#declare DO_CHAIR_INC = version
#version 3

#include "colors.inc"
#include "woods.inc"

#declare G1 = texture { pigment { color Gold }
                        finish { specular .3 reflection .7 } }
#declare S1 = texture { pigment { color Silver }
                        finish { specular .3 reflection .7 } }
#declare W1 = texture { T_Wood24 rotate <45,45,45> }

#declare SeatTexture =
texture {
   pigment { color rgb <.02, .24, .01> }
   normal { bumps .2 scale .02 }
   }

#declare Seat1Pt1 =
difference {
   superellipsoid { <.4,.4> texture { SeatTexture }
                    scale <.25, 0.10, .25> }
   box { <-1,-1,-1>, <1, 0, 1> }
   }

#declare Seat1Pt2 =
difference {
   superellipsoid { <.4, .4> texture { W1 scale <5, .2, 5> }
                    scale <.25, 0.04, .25> }
   box { <-1,0,-1>, <1,1,1> }
   }

#declare Seat1 = union {
   object { Seat1Pt1 }
   object { Seat1Pt2 }
   }

#declare Leg1Pt1 =
   difference {
      intersection {
         box { <-.1, 0, -.03>, <.1, .36, .03> }
         cylinder { <1, 0.18, -.1>, <1, 0.18, .1>, 1 }
         }
      cylinder { <1.04, 0.12, -.1>, <1.04, 0.12, .1>, 1 }
      box { <-.2,-.1, -0.1>,  <.2, .4, -0.02> rotate x*-1.6 }
      box { <-.2,-.1,  0.02>, <.2, .5, 0.1>   rotate x*1.6 }
      translate x*-0.04 scale <.7,1,1>
      }

#declare Leg1Pt2 =
   object { Leg1Pt1 scale <1.4, 1, .4> }

#declare Leg1Pt3 =
   cylinder { <-0.01, -0.015, -0.02>, <-0.01, -0.015, 0.02>, 0.025 }

#declare Leg1 =
union {
   object { Leg1Pt1 }
   object { Leg1Pt2 }
   object { Leg1Pt3 }
   translate y*0.04
   texture { W1 scale <.2, 5, .2> }
   }

#declare Arm1Pt1 =
union {
   object { Leg1Pt1 }
   object { Leg1Pt3 }
   translate y*-.36 rotate y*90 rotate x*90
   scale <5, .9, 1>
   translate <-.30, .65, .28>
   }

#declare Arm1 =
intersection {
   object { Arm1Pt1 }
   torus { .58,.02 scale <1,4.5,1> translate <.28,.65,0> }
   texture { W1 scale <.2, .2, 4> }
   }

#declare Arm2Pt1 =
union {
   object { Leg1Pt1 }
   object { Leg1Pt3 }
   translate y*-.36 rotate y*90 rotate x*90
   scale <5, 1.2, 1>
   translate <.30, .65, .28>
   }

#declare Arm2 =
intersection {
   object { Arm2Pt1 }
   torus { .58,.02 scale <1,5,1> translate <-.28,.65,0> }
   texture { W1 scale <.2, .2, 4> }
   }

#declare ArmS =
intersection {
   box { <-.35,.4,0>, <.35,.65,.02> }
   torus { .31, .015 rotate x*90 scale <1,2,1> translate <0,.8,.01> }
   texture { W1 scale <.2, 2, .2> }
   }

#declare Chbh = 0.60
#declare Ch1B1 =
   difference {
      cylinder { <0,0,-.01>, <0,0,.01>, .1025 }
      cylinder { <-.01,0,-.1>, <-.01,0,.1>, 0.0975 }
      box { <-1,-1,-1>, <0,1,1> }
      box { <-1,0,-1>, <1,1,1> }
      scale <1,3,1>  translate y*.3
      }

#declare Ch1B2 =
   union {
      object { Ch1B1 }
      object { Ch1B1 rotate y*180 translate x*0.10 }
      }

#declare Ch1B3 =
   union {
      object { Ch1B2 }
      object { Ch1B2 translate x*0.10 }
      }

#declare Ch1B4 =
   union {
      object { Ch1B3 }
      object { Ch1B3 rotate x*180 }
      }

#declare Ch1B5 =
   union {
      object { Ch1B4 }
      object { Ch1B4 rotate y*180 }
      intersection {
         torus { 2, .015 rotate x*90 translate <2.2,0,0> }
         box { <-1,0,-.01>, <1, 0.6, .01> }
         translate y*-.3
      }
      intersection {
         torus { 2, .015 rotate x*90 translate <-2.2,0,0> }
         box { <-1,0,-.01>, <1, 0.6, .01> }
         translate y*-.3
      }
      box { <-.23, -.01, -.01>, <-.20, .01, .01> }
      box { < .20, -.01, -.01>, < .23, .01, .01> }
   }

#declare Ch1B6 =
   difference {
      intersection {
         object { Ch1B5 translate z*0.005 scale <1,1,100> } // extrude
         cylinder { <0,-1,-.5>, <0,2,-.5>, .55 }
         }
      cylinder { <0,-2,-.5>, <0,3,-.5>, .535 }
      texture { W1 scale <.2, 5, .2> }
   }

#declare Ch1Top1 =
   union {
      box { <-.05,.28,-.01>, <.05,.36,.01> }
      cylinder { <-.05,.32,-.01>, <-.05,.32,.01>, .04 } // center side
      cylinder { < .05,.32,-.01>, < .05,.32,.01>, .04 } // center other side
      cylinder { <-.28, .28, -.01>, <-.28, .28, .01>, .035 } // side
      cylinder { < .28, .28, -.01>, < .28, .28, .01>, .035 } // other side
      difference {
         torus { .25, .06 rotate x*90 translate <-.14, .08, 0.05 > }
         box { <-1,-1,-1>, <1,.3,1> }
      }
      difference {
         torus { .25, .06 rotate x*90 translate < .14, .08, .05 > }
         box { <-1,-1,-1>, <1,.3,1> }
      }
   }

#declare Ch1Top =
   difference {
      intersection {
         object { Ch1Top1 translate z*0.005 scale <1,1,100> } // extrude
         cylinder { <0,-1,-.5>, <0,2,-.5>, .56 }
         }
      cylinder { <0,-2,-.5>, <0,3,-.5>, .53 }
      texture { W1 scale <4,.25,.1> }
   }

#declare Ch1Back = union {
   object { Ch1Top }
   object { Ch1B6 }
   rotate x*10 // lean it back
   translate y*.70   // lift it to seat level
   translate z*.275   // put it at the back of the chair
   }

// ========== DO_Chair1 ========== //

#declare Ch1d = 0.19
#declare DO_Chair1 = union {
   object { Seat1 translate y*.40 }
   object { Leg1 rotate y*45  translate <-Ch1d, 0,  Ch1d> }
   object { Leg1 rotate y*135 translate < Ch1d, 0,  Ch1d> }
   object { Leg1 rotate y*225 translate < Ch1d, 0, -Ch1d> }
   object { Leg1 rotate y*315 translate <-Ch1d, 0, -Ch1d> }
   object { Ch1Back }
   }

// ========== DO_Chair2 ========== //

#declare DO_Chair2 =
union {
   object { DO_Chair1 }
   object { Arm1 }
   object { Arm2 }
   object { ArmS }
   }

// ========== DO_FootStool1 ========== //

#declare DO_FootStool1 = union {
   object { Seat1 translate y*.40 }
   object { Leg1 rotate y*45  translate <-Ch1d, 0,  Ch1d> }
   object { Leg1 rotate y*135 translate < Ch1d, 0,  Ch1d> }
   object { Leg1 rotate y*225 translate < Ch1d, 0, -Ch1d> }
   object { Leg1 rotate y*315 translate <-Ch1d, 0, -Ch1d> }
   scale <.7, .5, .5>
   }

// ========== DO_Stool1 ========== //

#declare SHeight = .6    // the exact height
#declare SRadius = .17   // the approximate radius of the top
#declare SThick = .025   // the thickness of the legs

#declare StoolTexture = texture {
   T_Wood18 rotate <45,45,45> scale <5,.2,.2> }

// The top

#declare STop = intersection {
   union {
      torus { SRadius-SThick/2, SThick translate y*-SThick/2 }
      cylinder { <0, -SThick-.01, 0>, <0, SThick+.01, 0>, SRadius }
      }
   cylinder { <0,-SThick,0>, <0,0,0>, SRadius+SThick }
   texture { StoolTexture }
   }

// The Legs

#declare SLeg = box {
   <-SThick/2, -SHeight, -SThick/2>, <SThick/2, -SThick/2, SThick/2>
   texture { StoolTexture rotate z*90 }
   }

#declare SLegs = union {
   #declare LegR = SRadius*.8
   #declare LegAngle = 10
   #declare Count = 0
   #while (Count < 4)
      object { SLeg
         rotate x*LegAngle
         translate z*-LegR
         rotate y*(Count*90 +45)
         translate y*SHeight
         }
      #declare Count = Count + 1
   #end
   }

// The braces

#declare X = tan(LegAngle*3.14159/180)*SHeight/3

#declare Brace1 = cylinder {
   <-LegR*.707-X*.707,0,0>, <LegR*.707+X*.707,0,0>, SThick/2.5
   texture { StoolTexture }
   }

#declare Brace2 = cylinder {
   <-LegR*.707-2*X*.707,0,0>, <LegR*.707+2*X*.707,0,0>, SThick/2.5
   texture { StoolTexture }
   }

#declare SBraces = union {
   object { Brace1 translate <0,SHeight*.667,-LegR*.707-X*.707> }
   object { Brace1 translate <0,SHeight*.667, LegR*.707+X*.707> }
   object { Brace1 rotate y*90 translate <-LegR*.707-X*.707,SHeight*.667+SThick,0> }
   object { Brace1 rotate y*90 translate < LegR*.707+X*.707,SHeight*.667+SThick,0> }

   object { Brace2 translate <0,SHeight*.333,-LegR*.707-2*X*.707> }
   object { Brace2 translate <0,SHeight*.333, LegR*.707+2*X*.707> }
   object { Brace2 rotate y*90 translate <-LegR*.707-2*X*.707,SHeight*.333+SThick,0> }
   object { Brace2 rotate y*90 translate < LegR*.707+2*X*.707,SHeight*.333+SThick,0> }
   }

// The Feet

#declare FootPt1 = union {
   torus { SThick/2.5, SThick/6 translate y*SThick/10
      }
   cylinder { <0,0,0>, <0,SThick,0>, SThick /3 }
   texture {
      pigment { color rgb <.7,.7,.7> }
      finish { phong .1 reflection .7 }
      }
   }

#declare Foot = difference {
   object { FootPt1 }
   box  { <-SThick,-SThick,-SThick>, <SThick,0,SThick> }
   }

#declare SFeet = union {
   object { Foot translate <-LegR*.707-3*X*.707,0,-LegR*.707-3*X*.707> }
   object { Foot translate <-LegR*.707-3*X*.707,0, LegR*.707+3*X*.707> }
   object { Foot translate < LegR*.707+3*X*.707,0,-LegR*.707-3*X*.707> }
   object { Foot translate < LegR*.707+3*X*.707,0, LegR*.707+3*X*.707> }
   }

#declare DO_Stool1 = union {
   object { SLegs }
   object { SBraces }
   object { SFeet }
   object { STop translate y*SHeight }
   }


// ========== DO_Chair3 ========== //
// a windsor style chair

#declare T1 = texture { T_Wood10 rotate <45,45,45> }

#declare SeatPt1 = intersection {
   superellipsoid { <.4,.4> rotate x*90 }
   box { <-1,-1,-1>, <1,1,0> }
   scale <1,.1,1>
   }

#declare SeatPt2 = intersection {
   superellipsoid { <.8,.4> rotate x*90 }
   box { <-1,-1,0>, <1,1,1> }
   scale <1,.1,1>
   }

#declare Seat = union {
   object { SeatPt1 }
   object { SeatPt2 }
   scale <.25,.25,.22>
   texture { T1 scale <.1,.1,5> }
   }

#declare Pole = intersection {
   sphere { 0,.15 scale <.4,10,.4> }
   box { <-1,-1,-1>, <1,1,1> }
   texture { T1 scale <.1,5,.1> }
   }

#declare Leg = object { Pole scale <.3,.23,.3> translate y*-.23 }

#declare A = 8
#declare Legs = union {
   object { Leg rotate z*A rotate x*A translate <.16,0,-.14> }
   object { Leg rotate z*-A rotate x*A translate <-.16,0,-.14> }
   object { Leg rotate z*A rotate x*-A translate <.16,0,.14> }
   object { Leg rotate z*-A rotate x*-A translate <-.16,0,.14> }
   }

#declare Lower = union {
   object { Seat translate y*.44 }
   object { Legs translate y*.44 }
   object { Pole scale <.25,.195,.25> rotate x*90 translate <-.20,.15,0> }
   object { Pole scale <.25,.195,.25> rotate x*90 translate < .20,.15,0> }
   object { Pole scale <.25,.210,.25> rotate z*90 translate <0,.15,.08> }
   object { Pole scale <.25,.210,.25> rotate z*90 translate <0,.15,-.08> }
   }

#declare Th = 0.025
#declare R = .23
#declare A = 9.46
#declare Top1 = difference {
   cylinder { <0,0,-Th/2>, <0,0,Th/2>, R+Th/2 }
   cylinder { <0,0,-Th/2-.001>, <0,0,Th/2+.001>, R-Th/2 }
   box { <-.5,-.5,-.1>, <0,0,.1> rotate z*A }
   box { <0,-.5,-.1>, <0.5,0,.1> rotate z*-A }
   }

#declare Top2 = union {
   object { Top1 }
   box { <-Th/2,-.3,-Th/2>, <Th/2,0,Th/2> translate x*-R rotate z*A }
   box { <-Th/2,-.3,-Th/2>, <Th/2,0,Th/2> translate x*R rotate z*-A }
   translate <0,.3,0>
   rotate x*10
   translate <0,0,.12>
   texture { T1 scale <.1,5,.1> }
   }

#declare X1L = .13
#declare X1T = .17
#declare Y1T = .45
#declare Z1L = .15
#declare Z1T = .20

#declare X2L = .08
#declare X2T = .11
#declare Y2T = .50
#declare Z2L = .18
#declare Z2T = .21

#declare X3L = .03
#declare X3T = .04
#declare Y3T = .52
#declare Z3L = .19
#declare Z3T = .215

#declare R = .008
#declare Top = union {
   object { Top2 }
   cylinder { <-X1L,0,Z1L>, <-X1T,Y1T,Z1T>, R }
   cylinder { < X1L,0,Z1L>, < X1T,Y1T,Z1T>, R }
   cylinder { <-X2L,0,Z2L>, <-X2T,Y2T,Z2T>, R }
   cylinder { < X2L,0,Z2L>, < X2T,Y2T,Z2T>, R }
   cylinder { <-X3L,0,Z3L>, <-X3T,Y3T,Z3T>, R }
   cylinder { < X3L,0,Z3L>, < X3T,Y3T,Z3T>, R }
   texture { T1 scale <.1,5,.1> }
   }

#declare DO_Chair3 = union {
   object { Lower }
   object { Top translate y*.44 }
   }

/*

// Uncomment one of the sections below to render an image

// Chair1, Chair2, and FootStool1
light_source { <-20,10,-20> color rgb <1,1,1> }
light_source { <10,12,-20> color rgb <1,1,1> }
light_source { <0,10,-1> color rgb <.7,.7,.7> }
camera { location <0,.8,-2> look_at <0,.6,0> }
object { DO_Chair2 rotate y*-45 translate x*-.6 }
object { DO_Chair1 rotate y*45  translate x*.6  }
object { DO_FootStool1 rotate y*45  translate <.1,0,-.4>  }
plane {  y,  0 texture { pigment { color <.7,.7,.7> } } }
plane {  x, -5 texture { pigment { color <.7,.7,.7> } } rotate y*35 }
plane { -z, -5 texture { pigment { color <.7,.7,.7> } } rotate y*35 }

// Stool1
camera { location <0,.5,-1> look_at <0,.3,0> }
light_source { <-20,10,-20> color rgb <1,1,1> }
light_source { <10,12,-20> color rgb <1,1,1> }
object { DO_Stool1 rotate y*20 }
plane {  y,  0 texture { pigment { color <.7,.7,.7> } } }
plane {  x, -5 texture { pigment { color <.7,.7,.7> } } rotate y*35 }
plane { -z, -5 texture { pigment { color <.7,.7,.7> } } rotate y*35 }


// Chair3
object { DO_Chair3 rotate y*-30 }
light_source { <-20,10,-20> color rgb <1,1,1> }
light_source { <10,12,-20> color rgb <1,1,1> }
camera { location <0,.6,-1.5> look_at <0,.44,0> }
plane {  y,  0 texture { pigment { color <.7,.7,.7> } } }
plane {  x, -5 texture { pigment { color <.7,.7,.7> } } rotate y*35 }
plane { -z, -5 texture { pigment { color <.7,.7,.7> } } rotate y*35 }
*/

#version DO_CHAIR_INC
#end
