// DO_Endtable1.inc
// The following objects are defined in this file:
//    DO_EndTable1
//       an end table with drawer and front doors
//       .6 x .6 x .6, exactly 0.60 in height
//       bottom center is at <0,0,0>
//       The table faces in the -z direction

#ifndef (DO_ENDTA_INC)
#declare DO_ENDTA_INC = version
#version 3

#include "colors.inc"
#include "woods.inc"

#declare G1 = texture { pigment { color Gold } finish { specular .3 reflection .7 } }
#declare W1 = texture { T_Wood24 rotate <45,45,45> }

// ========== End Table ========== //

#declare EToverhang = 0.03
#declare ETspacing = 0.05
#declare ETpanelthickness = 0.03
#declare ETbase = 0.20
#declare ETwidth = 1
#declare ETheight = 1
#declare ETknobr = 0.02

#declare ETDoor =
difference {
   box { <-ETwidth/2+EToverhang+ETspacing, ETbase+ETspacing, -ETwidth/2+EToverhang-ETpanelthickness>
         <-ETspacing/2, ETheight-ETpanelthickness-ETbase-ETspacing, -ETwidth/2+EToverhang> }
   cylinder { <-ETwidth/2+EToverhang+ETspacing, 0, -ETwidth/2+EToverhang-ETpanelthickness>,
              <-ETwidth/2+EToverhang+ETspacing, 1, -ETwidth/2+EToverhang-ETpanelthickness>,
                ETpanelthickness/2 }
   cylinder { <-ETspacing/2, 0, -ETwidth/2+EToverhang-ETpanelthickness>,
              <-ETspacing/2, 1, -ETwidth/2+EToverhang-ETpanelthickness>,
                ETpanelthickness/2 }
   cylinder { <-1, ETheight-ETpanelthickness-ETbase-ETspacing, -ETwidth/2+EToverhang-ETpanelthickness>,
              < 1, ETheight-ETpanelthickness-ETbase-ETspacing, -ETwidth/2+EToverhang-ETpanelthickness>,
                ETpanelthickness/2 }
   cylinder { <-1, ETbase+ETspacing, -ETwidth/2+EToverhang-ETpanelthickness>,
              < 1, ETbase+ETspacing, -ETwidth/2+EToverhang-ETpanelthickness>,
                ETpanelthickness/2 }
   texture { W1 scale <.2, 5, .2> }
   }

#declare ETDrawer =
difference {
   box { <-ETwidth/2+ETspacing, ETheight-ETpanelthickness-ETbase+ETspacing, -ETwidth/2-ETpanelthickness>
         < ETwidth/2-ETspacing, ETheight-ETpanelthickness-ETspacing, -ETwidth/2> }
   cylinder { <-ETwidth/2+ETspacing, 0, -ETwidth/2-ETpanelthickness>,
              <-ETwidth/2+ETspacing, 1, -ETwidth/2-ETpanelthickness>,
                ETpanelthickness/2  }
   cylinder { < ETwidth/2-ETspacing, 0, -ETwidth/2-ETpanelthickness>,
              < ETwidth/2-ETspacing, 1, -ETwidth/2-ETpanelthickness>,
                ETpanelthickness/2  }
   cylinder { <-1, ETheight-ETpanelthickness-ETspacing, -ETwidth/2-ETpanelthickness>,
              < 1, ETheight-ETpanelthickness-ETspacing, -ETwidth/2-ETpanelthickness>,
                ETpanelthickness/2 }
   cylinder { <-1, ETheight-ETpanelthickness-ETbase+ETspacing, -ETwidth/2-ETpanelthickness>,
              < 1, ETheight-ETpanelthickness-ETbase+ETspacing, -ETwidth/2-ETpanelthickness>,
                ETpanelthickness/2 }
   texture { W1 scale <5, .2, .2> }
   }

#declare ETBase =
difference {
   box { <-ETwidth/2, 0.00, -ETwidth/2>
         < ETwidth/2, ETbase, ETwidth/2> }
   box { <-ETwidth/2 + ETspacing*4, -1, -1>
         < ETwidth/2 - ETspacing*4, ETspacing, 1> }
   cylinder { <-ETwidth/2+ETspacing*4,0,-1>,
              <-ETwidth/2+ETspacing*4,0, 1>, ETspacing }
   cylinder { < ETwidth/2-ETspacing*4,0,-1>,
              < ETwidth/2-ETspacing*4,0, 1>, ETspacing }
   box { <-1, -1, -ETwidth/2 + ETspacing*4>
         < 1, ETspacing, ETwidth/2 - ETspacing*4> }
   cylinder { <-1, 0, -ETwidth/2+ETspacing*4>,
              < 1, 0, -ETwidth/2+ETspacing*4>, ETspacing }
   cylinder { <-1, 0,  ETwidth/2-ETspacing*4>,
              < 1, 0,  ETwidth/2-ETspacing*4>, ETspacing }
   texture { W1 scale <5,.2,5> }
   }

#declare ETLid =
difference {
   box { <-ETwidth/2-ETpanelthickness, ETheight-ETpanelthickness, -ETwidth/2-ETpanelthickness>
         < ETwidth/2+ETpanelthickness, ETheight, ETwidth/2+ETpanelthickness> }
   cylinder { <-1, ETheight, -ETwidth/2-ETpanelthickness>,
              < 1, ETheight, -ETwidth/2-ETpanelthickness>, ETpanelthickness/2 }
   cylinder { <-1, ETheight,  ETwidth/2+ETpanelthickness>,
              < 1, ETheight,  ETwidth/2+ETpanelthickness>, ETpanelthickness/2 }
   cylinder { <-ETwidth/2-ETpanelthickness, ETheight, -1>,
              <-ETwidth/2-ETpanelthickness, ETheight,  1>, ETpanelthickness/2 }
   cylinder { < ETwidth/2+ETpanelthickness, ETheight, -1>,
              < ETwidth/2+ETpanelthickness, ETheight,  1>, ETpanelthickness/2 }
   texture { W1 scale <5, .2, .2> }
   }

#declare DO_EndTable1 =
union {
   // the body
   box { <-ETwidth/2+EToverhang, ETbase, -ETwidth/2+EToverhang>
         < ETwidth/2-EToverhang, ETheight-ETpanelthickness, ETwidth/2-EToverhang> }
   object { ETBase }
   // the upper chunk
   box { <-ETwidth/2, ETheight-ETbase-ETpanelthickness, -ETwidth/2>
         < ETwidth/2, ETheight-ETpanelthickness, ETwidth/2> }
   object { ETDrawer }
   object { ETDoor }
   object { ETDoor translate <(ETwidth/2-EToverhang)-ETspacing/2,0,0> }
   object { ETLid }
   // the knobs
   sphere { <-ETspacing*2, ETheight/2, -ETwidth/2+EToverhang-ETpanelthickness-ETknobr>, ETknobr
            texture { G1 } }
   sphere { < ETspacing*2, ETheight/2, -ETwidth/2+EToverhang-ETpanelthickness-ETknobr>, ETknobr
            texture { G1 } }
   sphere { < 0, ETheight-ETpanelthickness-ETbase/2, -ETwidth/2-ETpanelthickness-ETknobr>, ETknobr
            texture { G1 } }
   scale 0.6
   }


// uncomment the section below to render a view of the end table
/*
object { DO_EndTable1 rotate y*30 }
plane {  y,  0 texture { pigment { color <.7,.7,.7> } } }
plane {  x, -5 texture { pigment { color <.7,.7,.7> } } rotate y*35 }
plane { -z, -5 texture { pigment { color <.7,.7,.7> } } rotate y*35 }
light_source { <-20,15,-20> color rgb <1,1,1> }
light_source { <10,12,-20> color rgb <1,1,1> }
camera { location <0,.7,-1.5> look_at <0,.4,0> }
*/

#version DO_ENDTA_INC
#end

