// DO_Lamps.inc
// The following objects are defined in this file:
//    DO_Lamp1 - standard lamp with gold and jade stand
//    DO_DeskLamp1 - small desk lamp, gold and jade stand

// The lamps will serve as light sources
// Bottom center of each lamp is at <0,0,0>

#ifndef (DO_LAMPS_INC)
#declare DO_LAMPS_INC = version
#version 3

#include "colors.inc"
#include "textures.inc"
#include "stones.inc"


// ========== DO_Lamp1 ========== //

// a lamp.  height .7
// bottom center is at <0,0,0>
// This lamp functions as a light source

#declare G1=
   texture { pigment { color Brass } finish { specular .3 reflection .3 } }

/*

#declare DO_Lamp1 =
union {
   light_source { <0,.75,0> color White
      }
   // the lamp shade
   cone { <0.0, 0.9, 0.0>, 0.16, <0.0, 0.6, 0.0>, 0.40 open
      texture {
         pigment { color rgbft <0.7, 0.7, 0.6, 0.4, 0.0> }
         finish { ambient 1.2 diffuse 0.5 }
         }
      }
   // the rims of the lamp shade
   torus { 0.16, 0.005 translate y*0.9 no_shadow texture { G1 } }
   torus { 0.40, 0.005 translate y*0.6 no_shadow texture { G1 } }
   // the bulb
   cylinder { <0,.60,0 >, <0, .68, 0>, 0.02 texture { G1 } }
   sphere { <0, .75, 0>, 0.07
      texture {
         pigment { color rgbft <1,1,1,1,1> }
         finish { ambient 1 }
         }
      }
   cylinder { <0, 0.58, 0 >, <0, 0.60, 0>, 0.071 texture { G1 } }
   // the stand
   cylinder { <0, 0.15, 0 >, <0, 0.60, 0>, .070 texture { pigment { Jade scale .3 } } }
   cylinder { <0, 0.05, 0 >, <0, 0.15, 0>, .071 texture { G1 } }
   torus { 0.07, 0.015 translate y*0.13 texture { G1 } }
   cylinder { <0, 0.05, 0 >, <0, 0.13, 0>, .08 texture { G1 } }
   torus { 0.08, 0.015 translate y*0.05 texture { G1 } }
   box { <-.1, .02, -.1> <.1, .05, .1> texture { G1 } }
   // the feet
   torus { 0.02, 0.01 translate <-.080, .01, -.080> texture { G1 } }
   torus { 0.02, 0.01 translate <-.080, .01,  .080> texture { G1 } }
   torus { 0.02, 0.01 translate < .080, .01, -.080> texture { G1 } }
   torus { 0.02, 0.01 translate < .080, .01,  .080> texture { G1 } }
   scale 0.7
}

*/


// ========== DO_DeskLamp ========== //

// a small desklamp, gold and jade, height .5
// bottom center is at <0,0,0>
// This lamp serves as a light source

#declare DLwidthtop = .12
#declare DLwidthbottom = .18
#declare DLshadeheight = .18
#declare DLheight = .5
#declare DLbase = .1
#declare DLradius1 = .015
#declare DLradius2 = .1
#declare DLtexture1 = texture { T_Stone24 scale .025 }
#declare DLtexture2 = texture { G1 }
#declare DLtexture3 =
   texture { pigment { color rgbft <0.7, 0.7, 0.6, 0.4, 0.0> }
             finish { ambient 1.2 diffuse 0.5 } }
#declare DLdecoradius = 0.002

#declare DLpanel1 = union {
   polygon { 4,
      <-DLwidthtop/2, DLheight, -DLwidthtop/2>
      < DLwidthtop/2, DLheight, -DLwidthtop/2>
      < DLwidthbottom/2, DLheight-DLshadeheight, -DLwidthbottom/2>
      <-DLwidthbottom/2, DLheight-DLshadeheight, -DLwidthbottom/2>
      texture { DLtexture3 }
      }
   // the spheres
   sphere   { <-DLwidthtop/2, DLheight, -DLwidthtop/2>,
              DLdecoradius*2 texture { DLtexture2 } }
   sphere   { <-DLwidthbottom/2, DLheight-DLshadeheight, -DLwidthbottom/2>,
              DLdecoradius*2 texture { DLtexture2 } }
   cylinder { <-DLwidthtop/2, DLheight, -DLwidthtop/2>,
              < DLwidthtop/2, DLheight, -DLwidthtop/2>,
              DLdecoradius texture { DLtexture2 } }
   cylinder { <-DLwidthtop/2, DLheight, -DLwidthtop/2>,
              <-DLwidthbottom/2, DLheight-DLshadeheight, -DLwidthbottom/2>,
              DLdecoradius texture { DLtexture2 } }
   cylinder { <-DLwidthbottom/2, DLheight-DLshadeheight, -DLwidthbottom/2>,
              < DLwidthbottom/2, DLheight-DLshadeheight, -DLwidthbottom/2>,
              DLdecoradius texture { DLtexture2 } }
   }

#declare DLShade = union {
   object { DLpanel1 }
   object { DLpanel1 rotate y*90 }
   object { DLpanel1 rotate y*180 }
   object { DLpanel1 rotate y*270 }
   // the top panel
   polygon { 4,
      <-DLwidthtop/2, DLheight,-DLwidthtop/2>
      < DLwidthtop/2, DLheight,-DLwidthtop/2>
      < DLwidthtop/2, DLheight, DLwidthtop/2>
      <-DLwidthtop/2, DLheight, DLwidthtop/2>
      texture { DLtexture3 }
      }
   }

#declare DLsleeveheight = 0.03
#declare DLsleeve = union {
   cylinder { <0, 0, 0>, <0, DLsleeveheight ,0>, DLradius1 }
   torus { DLradius1, DLradius1/5 }
   torus { DLradius1, DLradius1/5 translate y*DLsleeveheight/4 }
   torus { DLradius1, DLradius1/5 translate y*DLsleeveheight*3/4 }
   torus { DLradius1, DLradius1/5 translate y*DLsleeveheight }
   texture { DLtexture2 }
   }

#declare DLBase = union {
   cylinder { <0,0,0>, <0, DLsleeveheight, 0> DLradius1*4
      texture { DLtexture2 } }
   torus { DLradius1*4, DLradius1/5 translate y*DLradius1*2/5
      texture { DLtexture2 } }
   torus { DLradius1*4, DLradius1/5
      translate y*(DLsleeveheight-DLradius1*2/5)
      texture { DLtexture2 } }
   // the "sleeves" bottom to top
   object { DLsleeve scale <2,1,2> translate y*DLsleeveheight }
   object { DLsleeve scale <1,1,1> translate y*DLsleeveheight*2 }
   object { DLsleeve scale <1,1,1>
      translate y*(DLheight-DLshadeheight-DLsleeveheight*2) }
   object { DLsleeve scale <.8,1.4,.8>
      translate y*(DLheight-DLshadeheight-DLsleeveheight*1) }
   // the main shaft
   cylinder { <0, DLsleeveheight*3, 0>,
              <0, DLheight-DLshadeheight-DLsleeveheight*2>,
              DLradius1 texture { DLtexture1 } }
   }

#declare DLbulbradius = 0.03
#declare DLBulb = union {
   cylinder { <0, DLheight-DLshadeheight, 0 >,
              <0, DLheight-DLshadeheight*2/3-DLbulbradius, 0>,
              DLradius1/4 texture { DLtexture2 } }
   sphere { <0, DLheight-DLshadeheight*2/3, 0>, DLbulbradius
      texture {
         pigment { color rgbft <1,1,1,1,1> }
         finish { ambient .7 }
         }
      }
   light_source { <0, DLheight-DLshadeheight*2/3, 0> color Gray45
      fade_distance 1 fade_power 2 }
   }

#declare DLchainradius = 0.004
#declare DLy = DLheight-DLshadeheight
#declare DLChain = union {
   cylinder { <0, DLy, 0>
              <DLradius1*2, DLy, 0>,
              DLradius1/10 }
   #while (DLy > DLheight/3)
      sphere { <DLradius1*2, DLy, 0>, DLchainradius }
      #declare DLy = DLy - DLchainradius*2
   #end
   sphere { <DLradius1*2, DLy, 0>, DLchainradius*2 }
   texture { DLtexture2 }
   }

#declare DO_DeskLamp1 = union {
   object { DLShade }
   object { DLBase }
   object { DLBulb }
   object { DLChain }
   }

// uncomment the section below to render an image of the lamps
/*
object { DO_Lamp1 rotate y*30 translate <-.25,0,.1> }
object { DO_DeskLamp1 rotate y*165 translate <.25,0,-.1> }
plane {  y,  0 texture { pigment { color <.9,.9,.9> } } }
plane {  x, -5 texture { pigment { color <.9,.9,.9> } } rotate y*35 }
plane { -z, -5 texture { pigment { color <.9,.9,.9> } } rotate y*35 }
light_source { <-60,5,-200> color rgb <.4,.4,.4> }
//light_source { <10,12,-20> color rgb <.3,.3,.3> }
camera { location <0,.5,-1.2> look_at <0,.4,0> }
*/

#version DO_LAMPS_INC
#end
