// ************************************************************************
// DO_Table.inc                                     edited Dec 1998
//    DEFINE: DO_Table3
//       A wooden table, looks like pine or beechwood
//       goes well with the Windsor style chair
//       height, length, and width are set below; units are roughly in meters
//       bottom center is at <0,0,0>
// ************************************************************************

#ifndef (DO_TABLE_INC)
#declare DO_TABLE_INC = version
#version 3

//#include "colors.inc"
//#include "textures.inc"
//#include "woods.inc"

#declare Width  = 0.90
#declare Length = 1.22
#declare Height = 0.74
#declare Th = 0.03

#declare T1 = texture { T_Wood10 rotate <45,45,45> }

// ************************************************************************

#declare Top = union {
   box { <-Length/2+Th/3,-Th,-Width/2>, <Length/2-Th/3,-Th/3,Width/2> }
   box { <-Length/2,-Th,-Width/2+Th/3>, <Length/2,-Th/3,Width/2-Th/3> }
   // edges
   cylinder { <-Length/2+Th/3,-Th/3,-Width/2+Th/3>, < Length/2-Th/3,-Th/3,-Width/2+Th/3>, Th/3 }
   cylinder { <-Length/2+Th/3,-Th/3, Width/2-Th/3>, < Length/2-Th/3,-Th/3, Width/2-Th/3>, Th/3 }
   cylinder { <-Length/2+Th/3,-Th/3,-Width/2+Th/3>, <-Length/2+Th/3,-Th/3, Width/2-Th/3>, Th/3 }
   cylinder { < Length/2-Th/3,-Th/3,-Width/2+Th/3>, < Length/2-Th/3,-Th/3, Width/2-Th/3>, Th/3 }
   // corners
   cylinder { <-Length/2+Th/3,-Th,-Width/2+Th/3>, <-Length/2+Th/3,-Th/3,-Width/2+Th/3>, Th/3 }
   cylinder { < Length/2-Th/3,-Th,-Width/2+Th/3>, < Length/2-Th/3,-Th/3,-Width/2+Th/3>, Th/3 }
   cylinder { <-Length/2+Th/3,-Th, Width/2-Th/3>, <-Length/2+Th/3,-Th/3, Width/2-Th/3>, Th/3 }
   cylinder { < Length/2-Th/3,-Th, Width/2-Th/3>, < Length/2-Th/3,-Th/3, Width/2-Th/3>, Th/3 }
   // corners
   sphere { <-Length/2+Th/3,-Th/3,-Width/2+Th/3>, Th/3 }
   sphere { <-Length/2+Th/3,-Th/3, Width/2-Th/3>, Th/3 }
   sphere { < Length/2-Th/3,-Th/3,-Width/2+Th/3>, Th/3 }
   sphere { < Length/2-Th/3,-Th/3, Width/2-Th/3>, Th/3 }
   // top
   box { <-Length/2+Th/3,-Th/3,-Width/2+Th/3>, <Length/2-Th/3,0,Width/2-Th/3> }
   texture { T1 scale <.1,.1,4> }
   }

// ************************************************************************

#declare Overhang1 = 0.075
#declare Overhang2 = 0.050

#declare LongSide = box {
   <-Length/2+Overhang1,-0.09,-Width/2+Overhang1>,
   < Length/2-Overhang1,0,-Width/2+Overhang1+Th>
   texture { T1 scale <3,.1,.1> }
   }

// ************************************************************************

#declare ShortSide = box {
   <-Length/2+Overhang1,-0.09,-Width/2+Overhang1>,
   <-Length/2+Overhang1+Th,0,Width/2-Overhang1>
   texture { T1 scale <.1,.1,3> }
   }

// ************************************************************************

#declare Leg = union {
   intersection {
      box { <-.04,-.12,-.04>, <.04,0,.04> }
      sphere { 0, 0.12 }
      }
   torus { .030, .005 translate y*-.120 }
   torus { .030, .010 translate y*-.130 }
   torus { .030, .005 translate y*-.140 }
   torus { .030, .005 translate y*-.145 }
   torus { .030, .010 translate y*-.155 }
   torus { .030, .005 translate y*-.165 }
   torus { .025, .007 translate y*-.170 }
   intersection {
      sphere { 0, .035 }
      box { <-.04,0,-.04>, <.04,.04,.04> }
      translate y*-.2
      }
   cone { <0,-.2,0>, .035, <0,-Height+Th,0>, .025 }
   torus { .025, .012 translate y*(-Height+Th+.10) }
   torus { .025, .012 translate y*(-Height+Th+.08) }
   texture { T_Wood10 scale <.1,2,.1> }
}

// ************************************************************************

#declare DO_Table3 = union {
   object { Top translate y*Height }
   object { LongSide translate y*(Height-Th/3) }
   object { LongSide rotate y*180 translate y*(Height-Th/3) }
   object { ShortSide translate y*(Height-Th/3) }
   object { ShortSide rotate y*180 translate y*(Height-Th/3) }
   object { Leg translate <-Length/2+Overhang2+.04,Height-Th,-Width/2+Overhang2+0.04> }
   object { Leg translate <-Length/2+Overhang2+.04,Height-Th, Width/2-Overhang2-0.04> }
   object { Leg translate < Length/2-Overhang2-.04,Height-Th, Width/2-Overhang2-0.04> }
   object { Leg translate < Length/2-Overhang2-.04,Height-Th,-Width/2+Overhang2+0.04> }
   }

// ************************************************************************

#version DO_TABLE_INC
#end

// ************************************************************************
// ************************************************************************
